<?php
  // Simple Contact Form
  // Topcode Website Services

  defined( 'ABSPATH' ) or die( 'Direct access is not permitted' );

  add_shortcode( 'simple_contact_form', 'tscf_contact_form' );
  function tscf_contact_form() {
    $to = get_option( 'tscf_email_address' );
    if( ! $to ) {
      tscf_print( '<p>Error: Sending address not set in Simple Contact Form settings.</p>' );
      return; 
    }
    
    ob_start();      
    
    tscf_print( '<div class="simple_contact_form">' );
    
    if ( isset( $_POST['tscf_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['tscf_nonce'] ) ), -1 ) ) {
      // nonce is valid
      $maybe_send = true;
      $show_form = false;
    } else {
      // nonce is missing or invalid
      $maybe_send = false;
      $show_form = true;
    }
    
    $human = isset( $_POST['human'] ) ? sanitize_text_field( wp_unslash( $_POST['human'] ) ) : '';
    $user_name = isset( $_POST['tscf_name'] ) ? sanitize_text_field( wp_unslash( $_POST['tscf_name'] ) ) : '';
    $user_email = isset( $_POST['tscf_email'] ) ? sanitize_text_field( wp_unslash( $_POST['tscf_email'] ) ) : '';
    $user_subject = isset( $_POST['tscf_subject'] ) ? sanitize_text_field( wp_unslash( $_POST['tscf_subject'] ) ) : '';
    $user_message = isset( $_POST['tscf_message'] ) ? sanitize_text_field( wp_unslash( $_POST['tscf_message'] ) ) : '';

    if( $maybe_send ) {
      $nr_errors = 0;
      
      $subject = 'Message from the '.get_option( 'blogname' ).' website'."\n\n";
      
      $message = '';
      
      // name
      if( get_option( 'tscf_name_field' ) ) {
        tscf_print( '<input type="hidden" name="tscf_name" value="'.$user_name.'">' );
        if( ! $user_name ) {
          tscf_print( '<p class="tscf_error">'.esc_html__( 'Error: Name field empty.', 'simple-contact-form' ).'</p>' );
          $nr_errors++;
        } else {
          $message = 'Sender: '.$user_name."\n\n";
        }
      }
      
      // email
      if( get_option( 'tscf_email_field' ) ) {
        tscf_print( '<input type="hidden" name="tscf_email" value="'.$user_email.'">' );
        if( ! $user_email ) {
          tscf_print( '<p class="tscf_error">'.esc_html__( 'Error: Email field empty.', 'simple-contact-form' ).'</p>' );
          $nr_errors++;
        } else {
          $message .= 'Email: '.$user_email."\n\n";
        }
      }
      
      // subject
      if( get_option( 'tscf_subject_field' ) ) {
        tscf_print( '<input type="hidden" name="tscf_subject" value="'.$user_subject.'">' );
        if( ! $user_subject ) {
          tscf_print( '<p class="tscf_error">'.esc_html__( 'Error: Subject field empty.', 'simple-contact-form' ).'</p>' );
          $nr_errors++;
        } else {
          $message .= 'Subject: '.$user_subject."\n\n";
        }
      }
      
      // message
      tscf_print( '<input type="hidden" name="tscf_message" value="'.$user_message.'">' );
      if( ! $user_message ) {
        tscf_print( '<p class="tscf_error">'.esc_html__( 'Error: Message field empty.', 'simple-contact-form' ).'</p>' );
        $nr_errors++;
      } else {
        $message .= 'Message: '.$user_message."\n\n";
      }
      
      if( 1 != $human ) {
        tscf_print( '<p class="tscf_error">'.esc_html__( 'Error: Form failed human check.', 'simple-contact-form' ).'</p>' );
        $nr_errors++;
      }
      
      if( $nr_errors ) {
        tscf_print( '<p class="tscf_error">'.esc_html__( 'Your form had errors. Your message was not sent.', 'simple-contact-form' ).'</p>' );
        $show_form = true;
      } else {
        // send email
        $headers = '';
        $outcome = wp_mail( $to, $subject, $message, $headers );
        // feedback
        if( $outcome ) {
          tscf_print( '<p>'.esc_html__( 'Your message has been sent, but sending an email does not guarantee it will be delivered.', 'simple-contact-form' ).'<p>' );
          $show_form = false;
        } else {
          tscf_print( '<p>'.esc_html__( 'Error: Your message was not sent.', 'simple-contact-form' ).'</p>' );
          $show_form = true;
        }
      }
    }
      
    if( $show_form ) {
      // show the form
      tscf_print( '<form method="post" enctype="multipart/form-data">' );
      wp_nonce_field( -1, 'tscf_nonce', true, true );
      
      if( get_option( 'tscf_name_field' ) ) {
        tscf_print( '<p><label for="tscf_name">'.esc_html__( 'Your name:', 'simple-contact-form' ).'</label><br>' );
        tscf_print( '<input type="text" id="tscf_name" name="tscf_name" value="'.$user_name.'"></p>' );
      }
      
      if( get_option( 'tscf_email_field' ) ) {
        tscf_print( '<p><label for="tscf_sender">'.esc_html__( 'Your email address:', 'simple-contact-form' ).'</label><br>' );
        tscf_print( '<input type="text" id="tscf_sender" name="tscf_email" value="'.$user_email.'"></p>' );
      }
      
      if( get_option( 'tscf_subject_field' ) ) {
        tscf_print( '<p><label for="tscf_subject">'.esc_html__( 'Subject:', 'simple-contact-form' ).'</label><br>' );
        tscf_print( '<input type="text" id="tscf_subject" name="tscf_subject" value="'.$user_subject.'"></p>' );
      }
      
      tscf_print( '<p><label>Your message:</label><br>' );
      tscf_print( '<textarea name="tscf_message" rows="8">'.$user_message.'</textarea></p>' );
      
      tscf_print( '<p>'.esc_html__( 'Have to ask, are you human?', 'simple-contact-form' ).' <input type="checkbox" name="human" value="1"></p>' );
      
      tscf_print( '<p><input type="submit" value="Send" class="button" /></p>' );
      
      tscf_print( '</form>' );
    }
    tscf_print( '</div>' );
    return ob_get_clean();
  } // end function