<?php
  // Simple Contact Form
  // Topcode Website Services

  defined( 'ABSPATH' ) or die( 'Direct access is not permitted' );

  // set default options
  // add_option() will not change the option if it exists

  $to = get_option( 'admin_email' ); // default email address for messages
  add_option( 'tscf_email_address', $to );
  add_option( 'tscf_name_field', 1 );
  add_option( 'tscf_email_field', 1 );
  add_option( 'tscf_subject_field', 1 );

  function tscf_settings() {
    if ( !current_user_can( 'manage_options' ) )  {
      wp_die( esc_html__( 'You do not have permission to access this page.', 'simple-contact-form' ) );
    }
    tscf_print( '<div class="wrap">' );
    tscf_print( '<h2>'.esc_html__( 'Simple Contact Form', 'simple-contact-form' ).'</h2>' );
    tscf_print( '<p class="tscf_help">To use the form, put the shortcode: [simple_contact_form] on a page.</p>' );
    tscf_print( '<form method="post" action="options.php" enctype="multipart/form-data" novalidate="novalidate">' );
    // settings_fields( option_group )
    settings_fields( 'tscf_general' );
    // do_settings_sections( page )
    do_settings_sections( 'tscf_general' );
    submit_button();
    tscf_print( '</form>' );
    tscf_print( '</div>' ); // end wrap div
  } // end function

  // setup the settings

  function tscf_setup_setting( $data ) {
    // add_settings_field( id, title, callable, page, section, array $args )
    $args = array(
      'id' => $data['name'],
      'name' => $data['name'],
      'current_value' => get_option( $data['name'] ),
      'help' =>  $data['help']
    );
    add_settings_field( $data['name'], $data['label'], $data['input'], $data['page'], $data['section'], $args );
    // register_setting( option_group, option_name, array $args )
    $args = array(
      'type' => 'string',
      'description' => esc_html__( 'Simple Contact Form', 'simple-contact-form' ),
      'sanitize_callback' => $data['validate'],
      'show_in_rest' => false,
      'default' => get_option( $data['name'] )
    );
    register_setting( $data['group'], $data['name'], $args );
  }

  add_action( 'admin_init', 'tscf_setup_settings' );
  function tscf_setup_settings() {
    
    // add_settings_section( id, title, callback, page )
    $section_title = __( 'General', 'simple-contact-form' );
    add_settings_section( 'tscf_general', $section_title, '', 'tscf_general' );

    // email address
    $data = array (
      'group' => 'tscf_general',
      'page' => 'tscf_general',
      'section' => 'tscf_general',
      'name' => 'tscf_email_address',
      'label' => esc_html__( 'Email address', 'simple-contact-form' ),
      'input' => 'tscf_text_input',
      'help' => esc_html__( 'The email address to which contact messages should be sent', 'simple-contact-form' ),
      'validate' => 'tscf_validate_email'
    );
    tscf_setup_setting ( $data );

    // show name field
    $data = array (
      'group' => 'tscf_general',
      'page' => 'tscf_general',
      'section' => 'tscf_general',
      'name' => 'tscf_name_field',
      'label' => esc_html__( 'Name field', 'simple-contact-form' ),
      'input' => 'tscf_radio_input',
      'help' => esc_html__( 'Whether to show the name field', 'simple-contact-form' ),
      'validate' => 'tscf_validate_radio'
    );
    tscf_setup_setting ( $data );

    // email address
    $data = array (
      'group' => 'tscf_general',
      'page' => 'tscf_general',
      'section' => 'tscf_general',
      'name' => 'tscf_email_field',
      'label' => esc_html__( 'Email field', 'simple-contact-form' ),
      'input' => 'tscf_radio_input',
      'help' => esc_html__( 'Whether to show the email field', 'simple-contact-form' ),
      'validate' => 'tscf_validate_radio'
    );
    tscf_setup_setting ( $data );

    // subject field
    $data = array (
      'group' => 'tscf_general',
      'page' => 'tscf_general',
      'section' => 'tscf_general',
      'name' => 'tscf_subject_field',
      'label' => esc_html__( 'Subject field', 'simple-contact-form' ),
      'input' => 'tscf_radio_input',
      'help' => esc_html__( 'Whether to show the subject field', 'simple-contact-form' ),
      'validate' => 'tscf_validate_radio'
    );
    tscf_setup_setting ( $data );
  } // end function

  // input functions

  function tscf_text_input( $args ) {
    $name = $args['name'];
    $current_value = $args['current_value'];
    tscf_print( '<input type="text" name="'.$name.'" value="'.$current_value.'">' );
    tscf_help( $args );
  } // end function

  function tscf_radio_input( $args ) {
    $name = $args['name'];
    $current_value = $args['current_value'];
    tscf_print_radio_button( 1, $current_value, $name, 'Show');
    tscf_print( '<br>' );
    tscf_print_radio_button( 0, $current_value, $name, 'Don\'t show' );
    tscf_help( $args );
  } // end function

  // validation

  function tscf_validate_email( $value ) {
    if( ! is_email( $value ) ) {
      // add_settings_error( string $setting, string $code, string $message, string $type = 'error' );
      add_settings_error( 'tscf_email_address', 'tscf_email_error', 'Invalid email address', 'error' );
      $value = '';
    }
    return $value;
  } // end function
  
  function tscf_validate_radio( $value ) {
    $value = intval( $value );
    if( ! in_array( $value, array( 0, 1 ) ) ) {
      $value = 1;
    }
    return $value;
  } // end function

  // show help text

  function tscf_help ( $args ) {
    $help = $args['help'];
    if ( $help ) {
      tscf_print( '<p class="tscf_help">'.$help.'</p>' );
    }
  } // end function
  